function [header, v, vs, w, units, fn, np, fparam] = getdata(file)

# usage: [header, v, vs, w, units, fn, np, fparam] = getdata(file)
#
# Input   file       Name of input file
#
# Output  header     Title 
#         v          Array with flight velocities
#         vs         Array with vertical velocities
#         w          Array with weighting factors
#         units      Cell array with velocity units
#         fn         Name of approximation function
#         np         Number of parameters
#         fparam     Parameters of approximation function
#
# The function reads the input file. The structure of the input file
# is as follows:
#
# 1. Line:          Title
# 2. Line:          Unit of v  Unit of vs  fn fparam
#
# Following lines:  v  vs  [w]
#
# Units can be m/s or km/h.
#
# ---------------------------------------------------------------------
#
  fid = fopen(file, "rt");
  if (fid == -1)
     error("getdata: Could not open file %s", file);
  end

# Title

  header = fgetl(fid);

# Units, function name and function parameters

  params = strsplit(fgetl(fid), " ", true);
  units  = params(1:2);
  fn     = params{3};
  np     = length(params) - 3;
  if (np > 0)
     for k = 1 : np
         fparam(k) = sscanf(params{3+k}, "%f");
     end
  else
     fparam(1) = 0;
  end

# Data

  n = 0;
  line = fgetl(fid);
  while (line != -1)
     n++;
     [data, nr] = sscanf(line, "%g %g");
     vi(n, 1)  = data(1);
     vsi(n, 1) = data(2);
     if (nr == 3)
        wi(n) = data(3);
     else
        wi(n) = 1;
     endif
     line = fgetl(fid);
  end;

  fclose(fid);

# Data in ascending sort

  [v, ix] = sort(vi);
  vs      = vsi(ix);
  w       = wi(ix);

end
