function c = linearfit(f, x, y, w)

# usage: c = linearfit(f, x, y, w)
#
# Input   f           Function name or function handle of a function 
#                     which returns a matrix [f_j(x_i)]: 
#                     rows correspond to x_i, columns to f_j
#         x(n), y(n)  Data pairs (column vectors)
#         w(n)        Weighting factors (optional)
#
# Output  c(m)    Coefficient matrix
#
# The coefficient matrix is determined such that
#
#      y = f(x) * c
#
# is the best approximation to the data in the sense that
#
#        ([F][c]-[y])' [w]^2 ([F][c] - [y]) = Min.
#
# where [F] = [f_j(x_i)].
#
# ---------------------------------------------------------------------

# Check arguments

  if (nargin < 3 || nargin > 4 || nargout != 1)
     usage("c = linearfit(f, x, y, w)");
  end

  if (! isvector(x) || ! isreal(x))
     error("linearfit: second argument must be a real vector");
  end

  if (! isvector(y) || ! isreal(y))
     error("linearfit: third argument must be a real vector");
  end

  if (nargin == 4 && (! isvector(w) || ! isreal(w)))
     error ("linearfit: fourth argument must be a real vector");
  end

# Build matrices

  if (ischar(f))
     fct = str2func(f);
  else
     fct = f;
  end
  F   = fct(x);

  if (nargin == 4)
     W = diag(w);
     F = W * F;
     y = W * y;
  end

# Solve

  [Q, R, P] = qr(F, "0");
  c(P,1) = R \ (Q' * y);

end
