#! /usr/bin/octave -qf

# ---------------------------------------------------------------------
#           Programm zur Berechnung der Geschwindigkeitspolare
# ---------------------------------------------------------------------

# Aufruf:   polare <prefix>

# <prefix>  Prefix der Dateinamen
#
# Dateien:
#
#   <prefix>.inp   Eingabe      Titel
#                               Einheiten Funktion [Parameter]
#                               v  vs  [w] 
#   <prefix>.out   Ausgabe      Ergebnisse
#   <prefix>.png   Ausgabe      Polare
#
# ---------------------------------------------------------------------

  srcdir = "/media/DATA/Documents/Forschung/Polare/src";
  addpath(srcdir);


# Check arguments

  if (nargin != 1)
     error("polare.m <prefix>\n");
  endif

  arglist = argv();
  fname   = arglist{1};

# File names

  fninp  = strcat(fname, ".inp");
  fnout  = strcat(fname, ".out");
  fnpng  = strcat(fname, ".png");

# Read input data

  [header, v, vs, w, units, fn, np, fparam] = getdata(fninp);
  n = length(v);

# Unit factor

  if(strcmp(units{1}, "km/h") == 1)
    sE = 1 / 3.6;
  else
    sE = 1;
  end

# Approximation

  gn = str2func(fn);
  g = @(x) gn(x, fparam);
  c = linearfit(g, v, vs, w);

# Performance Data

  m   = n + 4 * (n - 1);
  va  = linspace(v(1), v(n), m)';
  vs2 = g(va) * c;

  [gmin, ix] = min(vs2 ./ va);
  Eopt = sE / gmin;
  vg   = va(ix);

# Output results

  vsa  = g(v) * c;
  dvs =  vsa - vs;

  dvmax  = max(abs(dvs));
  dvmean = sqrt(dvs' * dvs) / n;

  dvs  = dvs * 100 ./ vs;

  E    = (v ./ vs) * sE;
  Ea   = (v ./ vsa) * sE;
  dE   = (Ea ./ E - 1) * 100;

  [vsm, ix] = min(vs2);
  vm        = va(ix);

  fid = fopen(fnout, "wt");

  fprintf(fid, "%s\n", header)
  fprintf(fid, "\n  Einheiten: [v] = %s, [vs] = %s\n", ...
          units{1}, units{2});
  fprintf(fid, "\n  Approximationsfunktion: %s\n", fn)
  if (np > 0)
     fprintf(fid, "  Parameter     : ");
      for k = 1 : np
          fprintf(fid, " %10.6g", fparam(k));
      end
      fprintf(fid, "\n");
  end
  nc = length(c);
  fprintf(fid, "  c             : ");
  for k = 1 : nc
      fprintf(fid, " %10.6g", c(k));
  end
  fprintf(fid, "\n");      

  fprintf(fid, "  Größter Fehler:   %6.3f", dvmax);
  fprintf(fid, "  Mittlerer Fehler:   %6.3f\n", dvmean);

  fprintf(fid, "\n  Geringstes Sinken: %5.2f %s bei %6.2f %s", ...
          vsm, units{2}, vm, units{1});
  fprintf(fid, "\n  Beste Gleitzahl  : %5.2f bei %6.2f %s\n", ...
          Eopt, vg, units{1});

  fprintf(fid, "\n    v       w      vs     vsa      dvs      E    Ea     dE\n")
  for k = 1 : n
      fprintf(fid, ...
         "  %6.2f  %5.2f  %5.2f   %5.2f  %6.2f%%   %4.1f  %4.1f  %5.2f%%\n", ...
         v(k), w(k), vs(k), vsa(k), dvs(k), E(k), Ea(k), dE(k));
  end;

  fclose(fid);

# Plot results

  figure(1, "visible", "off", "paperposition", [0, 0, 5.9, 3.5]);

  plot(v, -vs, "@", "marker", "o", "markersize", 5, ...
       va, -vs2, "linewidth", 2, "color", "red");
  legend("M", fn);
  grid("on");
  xlabel(strcat("v [", units{1}, "]"));
  ylabel(strcat("vs [", units{2}, "]"));
  title(header);

  print(fnpng, "-dpng");
